<?php
/*
Plugin Name: Mount Olive Pictures
Plugin URI: http://rinaldo.net/projects/mount-olive-pictures
Description: Insert picture gallery using shortcode
Version: 1.0.0
Date: 20 July 2019
Author: Bery Rinaldo <bery@rinaldo.net>
Author URI: http://rinaldo.net/
*/

/*
	Copyright 2018-2019 Bery Rinaldo

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 2, as 
	published by the Free Software Foundation. A copy of the license is at
	http://www.gnu.org/licenses/gpl-2.0.html

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
*/

/*
Note: This plugin requires WordPress version 4.3.1 or higher.

Information about the Mount Olive Pictures plugin along with
instructions and examples can be found here:

http://rinaldo.net/projects/mount-olive-pictures

[mount_olive_pictures]

This is limited to one instance per page or post.
*/

#define( 'WP_DEBUG', true );

if( ! function_exists('bjrsu_mount_olive_pictures') )
{
	function bjrsu_mount_olive_pictures_init_external()
	{
    		global $wp_rewrite;
    		$plugin_url = plugins_url( 'display.php', __FILE__ );
    		$plugin_url = substr( $plugin_url, strlen( home_url() ) + 1 );
    		// The pattern is prefixed with '^'
    		// The substitution is prefixed with the "home root", at least a '/'
    		// This is equivalent to appending it to `non_wp_rules`
    		#$wp_rewrite->add_external_rule( 'month.php$', $plugin_url );
		$wp_rewrite->add_external_rule( '^pictures/([\w\d_-]+)/?', '$plugin_url?d=$1' );
	}
	add_action( 'init', 'bjrsu_mount_olive_pictures_init_external' );

	function bjrsu_mount_olive_pictures_add_query_vars($vars)
	{
		$vars[] = 'display';
		$vp = end($vars);
# print "<!-- DEBUG: bjrsu_mount_olive_pictures_add_query_vars $vars $vp -->\n";
		return $vars;
	}

	// hook add_query_vars function into query_vars
	add_filter('query_vars', 'bjrsu_mount_olive_pictures_add_query_vars');

	function bjrsu_mount_olive_pictures($content)
	{
		global $bjrsu_filter_display;
		$bjrsu_filter_display = "";
		$bjrsu_filter_display = get_query_var('display');
#print "<!-- DEBUG: bjrsu_filter_display $bjrsu_filter_display -->\n";
		$bjrsu_filter_display = stripslashes( $bjrsu_filter_display );
#print "<!-- DEBUG: bjrsu_filter_display $bjrsu_filter_display -->\n";

		$bjrsu_content = $content;
		preg_match_all('!\[mount_olive_pictures\]!is',$bjrsu_content,$bjrsu_matches);
		$bjrsu_nummatches = count($bjrsu_matches[0]);
		for( $bjrsu_i=0; $bjrsu_i<$bjrsu_nummatches; $bjrsu_i++ )
		{
#print "<!-- DEBUG: bjrsu_mount_olive_pictures match $bjrsu_i $bjrsu_matches[1][$bjrsu_i] -->\n";
			$bjrsu_replacement = bjrsu_mount_olive_pictures_generate($bjrsu_matches[1][$bjrsu_i]);
			$bjrsu_content = preg_replace('/'.preg_quote($bjrsu_matches[0][$bjrsu_i],'/').'/',$bjrsu_replacement,$bjrsu_content,1);
#print "<!-- DEBUG: bjrsu_mount_olive_pictures match $bjrsu_i $bjrsu_matches[1][$bjrsu_i] -->\n";
		}

		return $bjrsu_content;
	}
	add_filter( 'the_content', 'bjrsu_mount_olive_pictures', 9 );


	function bjrsu_mount_olive_pictures_generate($kind)
	{
		global $bjrsu_html_string;
		$bjrsu_html_string = <<<HEADEOF
<SCRIPT LANGUAGE="JavaScript">
<!-- Begin
function popwindow(url)
{
  day = new Date();
  id = day.getTime();
  eval("page" + id + " = window.open(url, '" + id + "', 'toolbar=0,scrollbars=1,location=0,statusbar=0,menubar=0,resizable=1,width=800,height=700');");
}
// End -->
</SCRIPT>
<table id="photos" cellpadding="0" cellspacing=:0" width="100%" border="0">
HEADEOF;

#print "<!-- DEBUG: bjrsu_mount_olive_pictures_generate -->\n";

$eventsarray = array();

$hp = ABSPATH;
$motop = "mo-media/pictures";
$ppath = plugin_dir_url(__FILE__);
 
$picturesbase = "$hp$motop";

#print "<!-- DEBUG: pb $picturesbase -->\n";
$top = dir($picturesbase);
while($edir = $top->read()) {
#print "<!-- DEBUG: edir $edir -->\n";
  if ( $edir == "." || $edir == ".." ||
       substr($edir,0,2) == "._" || $edir == ".AppleDouble") {
    continue;
  }
  $event = $picturesbase . "/" . $edir;
  if (is_dir($event) && is_dir("$event/thumbnails") &&
      file_exists("$event/date.txt")) {
#print "<!-- DEBUG: date -->\n";
    $file_data = file("$event/date.txt");
    $event_date = rtrim($file_data[0]);
#print "<!-- DEBUG: event_date $event_date -- event $event -->\n";
    $eventsarray[$event_date] = $edir;
  }
}
#print "<!-- DEBUG: close dir -->\n";
$top->close();

#print "<!-- DEBUG: allkeys -->\n";
$allkeys = array_keys($eventsarray);
#print "<!-- DEBUG: rsort -->\n";
rsort($allkeys);

#print "<!-- DEBUG: loop allkeys -->\n";
foreach ($allkeys as $key) {
#print "<!-- DEBUG: key $key -->\n";
  $file_data = file("$picturesbase/$eventsarray[$key]/title.txt");
  $event = rtrim($file_data[0]);
#print "<!-- DEBUG: event $event -->\n";

  # print the first picture next to the link

  $file = "";
  if (file_exists("$picturesbase/$eventsarray[$key]/key.txt")) {
    # ooh, a key file, show that picure...easy peasy
    $key_data = file("$picturesbase/$eventsarray[$key]/key.txt");
    $file = rtrim($key_data[0]);
#print "<!-- DEBUG: keyfile $file -->\n";
  } else {
    # find first jpg file in thumbnails dir...fast and good enough
    $top = dir("$picturesbase/$eventsarray[$key]/thumbnails");
    while($file = $top->read()) {
#print "<!-- DEBUG: find $file -->\n";
      if ( $file == "." || $file == ".." || substr($file,0,2) == "._" ) {
        continue;
      }
      if ( preg_match("/.jpg$/",$file) ) {
#print "<!-- DEBUG: got it $file -->\n";
        break;
      }
    }
    $top->close();
  }


  $bjrsu_html_string .= "<tr><td><div class=\"thumbimgparawrap\"><a href=\"javascript:popwindow('${ppath}display.php?event=$eventsarray[$key]')\"><div class=\"thumbimgwrap\"><img height=\"75\" border=\"0\" src=\"../$motop/$eventsarray[$key]/thumbnails/$file\"></div>$event</a></div></td></tr>\n";
}

  $bjrsu_html_string .= "</table>\n";


		return "<div class=\"mountolivepictures\">$bjrsu_html_string</div>";
	}

} # if( ! function_exists('bjrsu_mount_olive_pictures') )

?>
